Module components

Module components 

Modules

merge_policies
queries
test_utils
tokenizers

Structs

IndexHolder
IndexRegistry
The main struct responsible for combining different indices and managing their lifetime.
IndexWriterHolder
Managing write operations to index
MorphologyManager
NamedFieldDocument
Internal representation of a document used for JSON serialization.
ProtoQueryParser
Responsible for casting crate::proto::Query message to tantivy::query::Query
QueryParser
SummaSegmentAttributes

Enums

DocumentParsingError
Error that may happen when deserializing a document from JSON.
IntermediateExtractionResult
QueryParserError
Possible error that may happen when parsing a query.
SummaDocument
Wrapper for carrying tantivy::Document from various sources

Constants

STOP_WORDS
List of stop words mixed for multiple languages

Traits

FruitExtractor
Extracts data from MultiFruit and moving it to the proto::CollectorOutput

Functions

build_fruit_extractor
cleanup_index
Cleanup after index deletion
default_tokenizers
Instantiate default tokenizers