IndexHolder

Struct IndexHolder 

pub struct IndexHolder { /* private fields */ }

Implementations

Source

impl IndexHolder

pub fn create_holder( core_config: &Config, index: Index, index_name: &str, index_engine_config: Arc<dyn ConfigProxy<IndexEngineConfig>>, merge_policy: Option<MergePolicy>, query_parser_config: QueryParserConfig, ) -> SummaResult<IndexHolder>

Sets up IndexHolder

pub fn create_memory_index(index_builder: IndexBuilder) -> SummaResult<Index>

Creates index and sets it up via setup

pub async fn open_remote_index<TExternalRequest: ExternalRequest + 'static, TExternalRequestGenerator: ExternalRequestGenerator<TExternalRequest> + 'static>( remote_engine_config: RemoteEngineConfig, read_hotcache: bool, ) -> SummaResult<Index>

pub fn compression(&self) -> Compression

Compression

pub fn index_attributes(&self) -> Option<&IndexAttributes>

Load index attributes from meta.json

pub fn conflict_strategy(&self) -> ConflictStrategy

How to resolve conflicts on inserting new documents

pub fn index_name(&self) -> &str

Index name

pub fn index_reader(&self) -> &IndexReader

IndexReader singleton

pub fn index(&self) -> &Index

Return internal Tantivy index

pub fn index_engine_config(&self) -> &Arc<dyn ConfigProxy<IndexEngineConfig>>

pub fn index_writer_holder( &self, ) -> SummaResult<&Arc<RwLock<IndexWriterHolder>>>

pub fn schema(&self) -> &Schema

Index schema

pub fn multi_fields(&self) -> &HashSet<Field>

Multi fields

pub fn real_directory(&self) -> &dyn Directory

Return internal Tantivy index

pub async fn partial_warmup<T: AsRef<str>>( &self, load_dictionaries: bool, fields: &[T], ) -> SummaResult<()>

Load term dictionaries into memory

pub async fn full_warmup(&self) -> SummaResult<()>

Load all index files into memory

pub async fn search_in_segments_async( &self, searcher: &Searcher, query: &dyn Query, collector: &MultiCollector<'_>, is_fieldnorms_scoring_enabled: Option<bool>, ) -> Result<MultiFruit>

Runs a query on the segment readers wrapped by the searcher asynchronously.

pub fn search_in_segments( &self, searcher: &Searcher, query: &dyn Query, collector: &MultiCollector<'_>, is_fieldnorms_scoring_enabled: Option<bool>, ) -> Result<MultiFruit>

pub fn search( &self, index_alias: &str, query: Query, collectors: Vec<Collector>, ) -> SummaResult<Vec<IntermediateExtractionResult>>

pub async fn custom_search_async( &self, index_alias: &str, query: Query, collectors: Vec<Collector>, is_fieldnorms_scoring_enabled: Option<bool>, load_cache: Option<bool>, store_cache: Option<bool>, ) -> SummaResult<Vec<IntermediateExtractionResult>>

Search query in the IndexHolder and collecting Fruit with a list of collectors

Search query in the IndexHolder and collecting Fruit with a list of collectors

pub async fn delete_documents(&self, query: Query) -> SummaResult<u64>

Delete SummaDocument by unq

pub async fn index_document( &self, document_bytes: &[u8], skip_updated_at_modification: bool, ) -> SummaResult<()>

Index generic SummaDocument

IndexUpdater bounds unbounded SummaDocument inside

pub async fn index_bulk( &self, documents: &Vec<Vec<u8>>, conflict_strategy: Option<ConflictStrategy>, ) -> SummaResult<(u64, u64)>

Index multiple documents at a time

pub fn space_usage(&self) -> SummaResult<SearcherSpaceUsage>

pub fn clear_collector_cache(&self)