pub struct IndexRegistry { /* private fields */ }Expand description
The main struct responsible for combining different indices and managing their lifetime.
Implementations
Sourceimpl IndexRegistry
impl IndexRegistry
pub fn new(core_config: &Arc<dyn ConfigProxy<Config>>) -> IndexRegistry
Sourcepub fn index_holders(
&self,
) -> &Arc<RwLock<HashMap<String, OwningHandler<IndexHolder>>>>
pub fn index_holders( &self, ) -> &Arc<RwLock<HashMap<String, OwningHandler<IndexHolder>>>>
Read-locked HashMap of all indices
pub async fn index_holders_cloned( &self, ) -> HashMap<String, Handler<IndexHolder>>
pub async fn clear(self)
Sourcepub async fn get_index_holder(
&self,
index_alias: &str,
) -> SummaResult<Handler<IndexHolder>>
pub async fn get_index_holder( &self, index_alias: &str, ) -> SummaResult<Handler<IndexHolder>>
Returns Handler to IndexHolder.
It is safe to keep Handler<IndexHolder> cause Index won’t be deleted until Handler is alive.
Though, IndexHolder can be removed from the registry of IndexHolders to prevent new queries
Sourcepub async fn get_index_holder_by_name(
&self,
index_name: &str,
) -> SummaResult<Handler<IndexHolder>>
pub async fn get_index_holder_by_name( &self, index_name: &str, ) -> SummaResult<Handler<IndexHolder>>
Retrieve IndexHolder by its name
Sourcepub async fn add(
&self,
index_holder: IndexHolder,
) -> SummaResult<Handler<IndexHolder>>
pub async fn add( &self, index_holder: IndexHolder, ) -> SummaResult<Handler<IndexHolder>>
Add new index to IndexRegistry
Sourcepub async fn finalize_extraction(
&self,
ie_results: Vec<IntermediateExtractionResult>,
) -> SummaResult<Vec<CollectorOutput>>
pub async fn finalize_extraction( &self, ie_results: Vec<IntermediateExtractionResult>, ) -> SummaResult<Vec<CollectorOutput>>
Merges several IntermediateExtractionResult