create_hotcache

Function create_hotcache 

pub fn create_hotcache(directory: Box<dyn Directory>) -> Result<Vec<u8>>
Given a tantivy directory, automatically identify the parts that should be loaded on startup and writes a static cache file called hotcache in the output.

See HotDirectory for more information.