pub struct CachingDirectory { /* private fields */ }Expand description
The caching directory is a simple cache that wraps another directory.
Implementations
Sourceimpl CachingDirectory
impl CachingDirectory
Sourcepub fn bounded(
underlying: Arc<dyn Directory>,
_capacity_in_bytes: usize,
file_stats: FileStats,
) -> CachingDirectory
pub fn bounded( underlying: Arc<dyn Directory>, _capacity_in_bytes: usize, file_stats: FileStats, ) -> CachingDirectory
Creates a new CachingDirectory.
Warming: The resulting CacheDirectory will cache all information without ever removing any item from the cache.
pub fn unbounded( underlying: Arc<dyn Directory>, file_stats: FileStats, ) -> CachingDirectory