DebugProxyDirectory

Struct DebugProxyDirectory 

pub struct DebugProxyDirectory { /* private fields */ }
The debug proxy wraps another directory and simply acts as a proxy recording all of its read operations.

It has two purpose

  • It is used when building our hotcache, to identify the file sections that should be in the hotcache.
  • It is used in the search-api to provide debugging/performance information.

Implementations

Source

impl DebugProxyDirectory

pub fn wrap(directory: Box<dyn Directory>) -> Self

Wraps another directory to log all of its read operations.

pub fn drain_read_operations(&self) -> impl Iterator<Item = ReadOperation> + '_

Returns all of the existing read operations.

Calling this “drains” the existing queue of operations.