pub struct DeletionMeta {
pub id: String,
pub num_deleted: u32,
}Expand description
A compact metadata reference to one immutable visibility generation.
Fields
id: StringIndependently tracked file identity, not the data segment identity.
num_deleted: u32Trait Implementations
Sourceimpl Clone for DeletionMeta
impl Clone for DeletionMeta
Sourceimpl Debug for DeletionMeta
impl Debug for DeletionMeta
Sourceimpl<'de> Deserialize<'de> for DeletionMeta
impl<'de> Deserialize<'de> for DeletionMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeletionMeta
Sourceimpl PartialEq for DeletionMeta
impl PartialEq for DeletionMeta
Sourceimpl Serialize for DeletionMeta
impl Serialize for DeletionMeta
impl StructuralPartialEq for DeletionMeta