pub struct SSTableBlockSize(/* private fields */);Expand description
Validated flush target for an STB5 data block. A single entry and its restart trailer may exceed the target, but never the reader safety limit.
Implementations