pub struct IndexHolder { /* private fields */ }Implementations
Sourceimpl IndexHolder
impl IndexHolder
Sourcepub fn create_holder(
core_config: &Config,
index: Index,
index_name: &str,
index_engine_config: Arc<dyn ConfigProxy<IndexEngineConfig>>,
merge_policy: Option<MergePolicy>,
query_parser_config: QueryParserConfig,
) -> SummaResult<IndexHolder>
pub fn create_holder( core_config: &Config, index: Index, index_name: &str, index_engine_config: Arc<dyn ConfigProxy<IndexEngineConfig>>, merge_policy: Option<MergePolicy>, query_parser_config: QueryParserConfig, ) -> SummaResult<IndexHolder>
Sets up IndexHolder
Sourcepub fn create_memory_index(index_builder: IndexBuilder) -> SummaResult<Index>
pub fn create_memory_index(index_builder: IndexBuilder) -> SummaResult<Index>
Creates index and sets it up via setup
pub async fn open_remote_index<TExternalRequest: ExternalRequest + 'static, TExternalRequestGenerator: ExternalRequestGenerator<TExternalRequest> + 'static>( remote_engine_config: RemoteEngineConfig, read_hotcache: bool, ) -> SummaResult<Index>
Sourcepub fn compression(&self) -> Compression
pub fn compression(&self) -> Compression
Compression
Sourcepub fn index_attributes(&self) -> Option<&IndexAttributes>
pub fn index_attributes(&self) -> Option<&IndexAttributes>
Load index attributes from meta.json
Sourcepub fn conflict_strategy(&self) -> ConflictStrategy
pub fn conflict_strategy(&self) -> ConflictStrategy
How to resolve conflicts on inserting new documents
Sourcepub fn index_name(&self) -> &str
pub fn index_name(&self) -> &str
Index name
Sourcepub fn index_reader(&self) -> &IndexReader
pub fn index_reader(&self) -> &IndexReader
IndexReader singleton
pub fn index_engine_config(&self) -> &Arc<dyn ConfigProxy<IndexEngineConfig>>
pub fn index_writer_holder( &self, ) -> SummaResult<&Arc<RwLock<IndexWriterHolder>>>
Sourcepub fn multi_fields(&self) -> &HashSet<Field>
pub fn multi_fields(&self) -> &HashSet<Field>
Multi fields
Sourcepub fn real_directory(&self) -> &dyn Directory
pub fn real_directory(&self) -> &dyn Directory
Return internal Tantivy index
Sourcepub async fn partial_warmup<T: AsRef<str>>(
&self,
load_dictionaries: bool,
fields: &[T],
) -> SummaResult<()>
pub async fn partial_warmup<T: AsRef<str>>( &self, load_dictionaries: bool, fields: &[T], ) -> SummaResult<()>
Load term dictionaries into memory
Sourcepub async fn full_warmup(&self) -> SummaResult<()>
pub async fn full_warmup(&self) -> SummaResult<()>
Load all index files into memory
Sourcepub async fn search_in_segments_async(
&self,
searcher: &Searcher,
query: &dyn Query,
collector: &MultiCollector<'_>,
is_fieldnorms_scoring_enabled: Option<bool>,
) -> Result<MultiFruit>
pub async fn search_in_segments_async( &self, searcher: &Searcher, query: &dyn Query, collector: &MultiCollector<'_>, is_fieldnorms_scoring_enabled: Option<bool>, ) -> Result<MultiFruit>
Runs a query on the segment readers wrapped by the searcher asynchronously.
pub fn search_in_segments( &self, searcher: &Searcher, query: &dyn Query, collector: &MultiCollector<'_>, is_fieldnorms_scoring_enabled: Option<bool>, ) -> Result<MultiFruit>
pub fn search( &self, index_alias: &str, query: Query, collectors: Vec<Collector>, ) -> SummaResult<Vec<IntermediateExtractionResult>>
Sourcepub async fn custom_search_async(
&self,
index_alias: &str,
query: Query,
collectors: Vec<Collector>,
is_fieldnorms_scoring_enabled: Option<bool>,
load_cache: Option<bool>,
store_cache: Option<bool>,
) -> SummaResult<Vec<IntermediateExtractionResult>>
pub async fn custom_search_async( &self, index_alias: &str, query: Query, collectors: Vec<Collector>, is_fieldnorms_scoring_enabled: Option<bool>, load_cache: Option<bool>, store_cache: Option<bool>, ) -> SummaResult<Vec<IntermediateExtractionResult>>
Search query in the IndexHolder and collecting Fruit with a list of collectors
Sourcepub fn custom_search(
&self,
index_alias: &str,
query: Query,
collectors: Vec<Collector>,
is_fieldnorms_scoring_enabled: Option<bool>,
load_cache: Option<bool>,
store_cache: Option<bool>,
) -> SummaResult<Vec<IntermediateExtractionResult>>
pub fn custom_search( &self, index_alias: &str, query: Query, collectors: Vec<Collector>, is_fieldnorms_scoring_enabled: Option<bool>, load_cache: Option<bool>, store_cache: Option<bool>, ) -> SummaResult<Vec<IntermediateExtractionResult>>
Search query in the IndexHolder and collecting Fruit with a list of collectors
Sourcepub async fn delete_documents(&self, query: Query) -> SummaResult<u64>
pub async fn delete_documents(&self, query: Query) -> SummaResult<u64>
Delete SummaDocument by unq
Sourcepub async fn index_document(
&self,
document_bytes: &[u8],
skip_updated_at_modification: bool,
) -> SummaResult<()>
pub async fn index_document( &self, document_bytes: &[u8], skip_updated_at_modification: bool, ) -> SummaResult<()>
Index generic SummaDocument
IndexUpdater bounds unbounded SummaDocument inside
Sourcepub async fn index_bulk(
&self,
documents: &Vec<Vec<u8>>,
conflict_strategy: Option<ConflictStrategy>,
) -> SummaResult<(u64, u64)>
pub async fn index_bulk( &self, documents: &Vec<Vec<u8>>, conflict_strategy: Option<ConflictStrategy>, ) -> SummaResult<(u64, u64)>
Index multiple documents at a time
pub fn space_usage(&self) -> SummaResult<SearcherSpaceUsage>
pub fn clear_collector_cache(&self)