pub struct HotDirectory { /* private fields */ }Expand description
The hot directory accelerates a given directory, by placing a static cache in front of a directory.
The HotDirectory does not implement write operations. It has been
designed for quickwit in order to regroup all of the small random
read operations required to open an index.
All of these operations are gather into a single file called the
hotcache.
Implementations
Sourceimpl HotDirectory
impl HotDirectory
Sourcepub fn open(
underlying: Box<dyn Directory>,
static_cache: StaticDirectoryCache,
) -> Result<HotDirectory>
pub fn open( underlying: Box<dyn Directory>, static_cache: StaticDirectoryCache, ) -> Result<HotDirectory>
Wraps an index, with a static cache serialized into hot_cache_bytes.